@@ -2,7 +2,7 @@ package Net::TacacsPlus::Packet::AccountReplyBody;
 
 =head1 NAME
 
-Net::TacacsPlus::Packet::AccountReplyBody - Tacacs+ accounting reply body
+Net::TacacsPlus::Packet::AccountReplyBody;
 
 =head1 DESCRIPTION
 
@@ -28,7 +28,7 @@ The accounting REPLY packet body
 =cut
 
 
-our $VERSION = '1.10_01';
+our $VERSION = '1.04';
 
 use strict;
 use warnings;
@@ -37,14 +37,6 @@ use 5.006;
 use Net::TacacsPlus::Constants 1.03;
 use Carp::Clan;
 
-use base qw{ Class::Accessor::Fast };
-
-__PACKAGE__->mk_accessors(qw{
-	status
-	server_msg
-	data
-});
-
 =head1 METHODS
 
 =over 4
@@ -55,13 +47,7 @@ Construct tacacs+ authorization response body object
 
 Parameters:
 
-	'raw_body' : raw body
-	
-	or
-	
-	status     : status of the reply
-	server_msg : message from server
-	data       : payload 
+	'raw_body': raw body
 
 =cut
 
@@ -69,13 +55,13 @@ sub new()
 {
 	my $class = shift;
 	my %params = @_;
+	my $self = {};
 	
-	#let the class accessor contruct the object
-	my $self = $class->SUPER::new(\%params);
+	bless $self, $class;
 
-	if ($params{'raw_body'}) {
-		$self->decode($params{'raw_body'});
-		delete $self->{'raw_body'};
+	if ($params{'raw_body'})
+	{
+		$self->decode($params{'raw_body'});	
 		return $self;
 	}
 
@@ -88,45 +74,50 @@ Extract status, server_msg and data from raw packet.
 
 =cut
 
-sub decode {
+sub decode($)
+{
 	my ($self, $raw_data) = @_;
 	
-	my ($server_msg_len, $data_len, $payload);
+	my ($server_msg_len,$data_len,$payload);
 	
-	(
-		$server_msg_len,
-		$data_len,
-		$self->{'status'},
-		$payload,
-	) = unpack("nnCa*", $raw_data);
+	( $server_msg_len,
+	$data_len,
+	$self->{'status'},
+	$payload,
+	) = unpack("nnCA*", $raw_data);
 	
-	(
-		$self->{'server_msg'},
-		$self->{'data'}
-	) = unpack("a".$server_msg_len."a".$data_len,$payload);
+	($self->{'server_msg'},
+	$self->{'data'}) = unpack("A".$server_msg_len."A".$data_len,$payload);
 }
 
-=item raw()
+=item server_msg()
 
-returns binary representation of Accounting Reply Body
+Return server message.
 
 =cut
 
-sub raw {
+sub server_msg()
+{
 	my $self = shift;
-		
-	return pack('nnCa*a*',
-		length($self->{'server_msg'}),
-		length($self->{'data'}),
-		$self->{'status'},
-		$self->{'server_msg'},
-		$self->{'data'},
-	);
+
+	return $self->{'server_msg'};
 }
 
+=item status()
+
+Return status.
+
+=cut
+
+sub status()
+{
+	my $self = shift;
+
+	return $self->{'status'};
+}
+
+1;
 
 =back
 
 =cut
-
-1;
