@@ -2,7 +2,7 @@ package Net::TacacsPlus::Packet::AuthenContinueBody;
 
 =head1 NAME
 
-Net::TacacsPlus::Packet::AuthenContinueBody - Tacacs+ authentication continue body
+Net::TacacsPlus::Packet::AuthenContinueBody;
 
 =head1 DESCRIPTION
 
@@ -25,7 +25,7 @@ Net::TacacsPlus::Packet::AuthenContinueBody - Tacacs+ authentication continue bo
 =cut
 
 
-our $VERSION = '1.10_01';
+our $VERSION = '1.03';
 
 use strict;
 use warnings;
@@ -34,14 +34,6 @@ use 5.006;
 use Net::TacacsPlus::Constants 1.03;
 use Carp::Clan;
 
-use base qw{ Class::Accessor::Fast };
-
-__PACKAGE__->mk_accessors(qw{
-	continue_flags
-	user_msg
-	data
-});
-
 =head1 METHODS
 
 =over 4
@@ -52,58 +44,27 @@ Construct tacacs+ authentication CONTINUE packet body object
 
 Parameters:
 
-	'continue_flags' : TAC_PLUS_CONTINUE_FLAG_ABORT - default none
-	'user_msg'       : user message requested by server
-	'data'           : data requested by server
+	'user_msg': user message requested by server
+	'data': data requested by server
+	'flags': TAC_PLUS_CONTINUE_FLAG_ABORT
 
 =cut
 
 sub new() {
 	my $class = shift;
 	my %params = @_;
+	my $self = {};
+	
+	bless $self, $class;
 
-	#let the class accessor contruct the object
-	my $self = $class->SUPER::new(\%params);
-
-	if ($params{'raw_body'}) {
-		$self->decode($params{'raw_body'});
-		delete $self->{'raw_body'};
-		return $self;
-	}
-
-	$self->continue_flags(0) if not defined $self->continue_flags;
+	$self->{'user_msg'} = $params{'user_msg'};
+	$self->{'data'} = $params{'data'};
+	$self->{'flags'} = $params{'continue_flags'} ? $params{'continue_flags'} : 0;
+#	$self->{''} = $params{''} ? $params{''} : TAC_PLUS_;
 
 	return $self;
 }
 
-
-=item decode($raw_body)
-
-Construct body object from raw data.
-
-=cut
-
-sub decode {
-	my ($self, $raw_body) = @_;
-
-	my $user_msg_length;
-	my $data_length;
-	my $payload;
-	
-	(
-		$user_msg_length,
-		$data_length,
-		$self->{'continue_flags'},
-		$payload,
-	) = unpack('nnCa*', $raw_body);
-
-	(
-		$self->{'user_msg'},
-		$self->{'data'},
-	) = unpack('a'.$user_msg_length.'a'.$data_length, $payload);
-}
-
-
 =item raw()
 
 Return binary data of packet body.
@@ -116,7 +77,7 @@ sub raw {
 	my $body = pack("nnC",
 		length($self->{'user_msg'}),
 		length($self->{'data'}),
-		$self->{'continue_flags'},
+		$self->{'flags'},
 	).$self->{'user_msg'}.$self->{'data'};
 
 	return $body;
