@@ -2,7 +2,7 @@ package Net::TacacsPlus::Packet::AuthenReplyBody;
 
 =head1 NAME
 
-Net::TacacsPlus::Packet::AuthenReplyBody - Tacacs+ authentication replay body
+Net::TacacsPlus::Packet::AuthenReplyBody;
 
 =head1 DESCRIPTION
 
@@ -24,7 +24,7 @@ REPLY packet) to the client. The REPLY packet body looks as follows:
 =cut
 
 
-our $VERSION = '1.10_01';
+our $VERSION = '1.03';
 
 use strict;
 use warnings;
@@ -33,15 +33,6 @@ use 5.006;
 use Net::TacacsPlus::Constants 1.03;
 use Carp::Clan;
 
-use base qw{ Class::Accessor::Fast };
-
-__PACKAGE__->mk_accessors(qw{
-	status
-	flags
-	server_msg
-	data
-});
-
 =head1 METHODS
 
 =over 4
@@ -59,19 +50,15 @@ Parameters:
 sub new {
 	my $class = shift;
 	my %params = @_;
+	my $self = {};
+	
+	bless $self, $class;
 
-	#let the class accessor contruct the object
-	my $self = $class->SUPER::new(\%params);
-
-	if ($params{'raw_body'}) {
-		$self->decode($params{'raw_body'});
-		delete $self->{'raw_body'};
+	if ($params{'raw_body'})
+	{
+		$self->decode($params{'raw_body'});	
 		return $self;
 	}
-	
-	# set default values
-	$self->server_msg('') if not defined $self->server_msg; 
-	$self->data('')       if not defined $self->data; 
 
 	return $self;
 }
@@ -87,42 +74,41 @@ sub decode {
 	
 	my ($server_msg_len,$data_len,$payload);
 	
-	(
-		$self->{'status'},
-		$self->{'flags'},
-		$server_msg_len,
-		$data_len,
-		$payload,
-	) = unpack("CCnna*", $raw_data);
+	( $self->{'status'},
+	$self->{'flags'},
+	$server_msg_len,
+	$data_len,
+	$payload,
+	) = unpack("CCnnA*", $raw_data);
 
 	$payload = '' if not defined $payload; #payload can be empty
 
-	(
-		$self->{'server_msg'},
-		$self->{'data'}
-	) = unpack("a".$server_msg_len."a".$data_len,$payload);
+	($self->{'server_msg'},
+	$self->{'data'}) = unpack("A".$server_msg_len."A".$data_len,$payload);
 }
 
+=item server_msg()
 
-=item raw()
-
-Return binary data of packet body.
+Return server message. 
 
 =cut
 
-sub raw {
+sub server_msg {
 	my $self = shift;
 
-	my $body = pack("CCnna*a*",
-		$self->{'status'},
-		$self->{'flags'},
-		length($self->{'server_msg'}),
-		length($self->{'data'}),
-		$self->{'server_msg'},
-		$self->{'data'},
-	);
+	return $self->{'server_msg'};
+}
 
-	return $body;
+=item status()
+
+Return status.
+
+=cut
+
+sub status {
+	my $self = shift;
+
+	return $self->{'status'};
 }
 
 1;
